@@ -169,15 +169,7 @@ C
 C ZERO IS FALSE APP.
        IF(RI.LE.MXSMP) GO TO 100
 C SIMPLE OBJECT?
-c   A bug was found here, where PRSO could get out of bounds
-c   for some few situations where ODO2 isn't used anyway. The
-c   array bounds error can cause a segmentation fault on some
-c   unix systems (Linux), but was apparently unnoticed on many
-c   other systems where the bounds error caused no problem.
-c                   -- "fix" by Rick Slater 10/15/98
-      if( (PRSO .lt. 221) .and. (PRSO .gt. 0) ) then
        IF(PRSO.NE.0) ODO2=ODESC2(PRSO)
-      end if
        IF(PRSI.NE.0) ODI2=ODESC2(PRSI)
        AV=AVEHIC(WINNER)
        FLOBTS=FLAMBT+LITEBT+ONBT
@@ -955,3 +947,4 @@ C DESCRIBE.
        RETURN
 C
        END
+
\ No newline at end of file
